/* 
 * Copyright (C) 2010, 2011  Cesar Rodriguez <cesar.rodriguez@lsv.ens-cachan.fr>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <arpa/inet.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include <err.h>
#include <fcntl.h>
#include <stdarg.h>
#include <assert.h>


char *bpos;

static unsigned int read_int ()
{
	int i = *(int*)bpos;
	bpos += sizeof(int);
	return i;
}

int mcisize(const char * infile)
{
	int i, e;
	int nb_cutoffs = 0;
	char *blob;
	struct stat statbuf;
	stat(infile,&statbuf);
	blob = malloc(statbuf.st_size);
	int fd = open(infile,O_RDONLY);
	read(fd,blob,statbuf.st_size);
	close(fd);
	bpos = blob;

	// start reading mci file
	int conds = read_int();
	int events = read_int();

	bpos += events * sizeof(unsigned int);
	for (i = 1; i <= conds; i++)
	{
		bpos += 2 * sizeof(unsigned int);
		while (read_int());
	}

	while ((e = read_int()))
	{
		++nb_cutoffs;
		read_int();
	}
	return events - nb_cutoffs;
}

void usage ()
{
	fprintf(stderr,
	"\nusage: mcisize <mcifile>\n\n"
	);
	exit(1);
}

int main (int argc, char ** argv)
{
	int i;
	char *filename = NULL;

	if (argc > 1) {
		filename = argv[1];
	}

	if (!filename) usage();

	int n = mcisize(filename);
	fprintf(stdout, "%d non-cutoff events\n", n);
	return 0;
}
